import setuptools
from inhoj.version import Version


setuptools.setup(name='inhoj',
                 version=Version('2.0.0').number,
                 description='Useful Python Code Snippets',
                 long_description=open('README.md').read().strip(),
                 author='Johni Douglas Marangon',
                 author_email='johni.douglas.marangon@gmail.com',
                 url='https://github.com/johnidm/inhoj',
                 packages=[
                     'inhoj',
                 ],
                 package_dir={'inhoj':
                              'inhoj'},
                 license='MIT License',
                 zip_safe=False,
                 keywords='inhoj',
                 classifiers=[
                     'Development Status :: 2 - Pre-Alpha',
                     'Intended Audience :: Developers',
                     'License :: OSI Approved :: MIT License',
                     'Natural Language :: English',
                     'Programming Language :: Python :: 3.5',
                 ])



import signal


class GracefulDeath():

    """
    Catch signals to allow graceful process shutdown

    Inspired in:
        - http://stackoverflow.com/questions/18499497/how-to-process-sigterm-signal-gracefully
        - https://github.com/ryran/reboot-guard/blob/master/rguard#L284:L304
    """

    def __init__(self):
        self.kill_now = False

        catch_signals = [
            signal.SIGTERM,
            signal.SIGINT,
            signal.SIGQUIT,
        ]

        for signum in catch_signals:
            signal.signal(signum, self.handle)

    def handle(self, signum, frame):
        self.kill_now = True



"""
Print in terminal with colors

Based in http://stackoverflow.com/a/34443116 and http://stackoverflow.com/a/17064509
"""

BLUE = '\033[94m'
GREEN = '\033[92m'
YELLOW = '\033[93m'
CYAN = '\033[96m'
RED = '\033[91m'
ENDC = '\033[0m'


def trace(text):
    print(CYAN + "{}".format(text) + ENDC)


def info(text):
    print(GREEN + "{}".format(text) + ENDC)


def warn(text):
    print(YELLOW + "{}".format(text) + ENDC)


def err(text):
    print(RED + "{}".format(text) + ENDC)
